Macros
- flush
- This macro flushes the trace buffer, sending any remaining trace records to the host.
- trace
- This macro creates a trace record with a message, or traces a block with entry/exit records.
Attribute Macros
- trace_
function - A procedural macro attribute for tracing function calls. This macro will create a trace record when the function is called