trace_function

Attribute Macro trace_function 

#[trace_function]
A procedural macro attribute for tracing function calls. This macro will create a trace record when the function is called

The trace record will contain the function name as a string. Note: This macro is intended to be used with the hyperlight_guest_tracing crate.